@@ -1,6 +1,6 @@
 package Bundle::AndyA;
 
-$VERSION = '1.11';
+$VERSION = '1.12';
 
 1;
 
@@ -70,6 +70,8 @@ Digest::MD5
 
 Digest::MD6
 
+Dist::Zilla
+
 Email::Address
 
 Email::Send
@@ -182,6 +184,8 @@ Parallel::Iterator
 
 Path::Class
 
+Path::Class::Each
+
 Perl::Tidy
 
 Perl::Version
@@ -240,8 +244,6 @@ WWW::Plurk
 
 XML::Descent
 
-XML::Twig
-
 YAML
 
 attributes
